@@ -20,11 +20,9 @@
  *	with this program; if not, write to the Free Software Foundation, Inc.,
  *	675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hotplug.c,v 1.6 2002/01/04 19:02:20 kroah Exp $
- * 
  */
 
-#include "stddef.h"
+#include <stdlib.h>
 #include "hotplug.h"
 #include "hotplug_version.h"
 
@@ -64,6 +62,6 @@ int main(int argc, char *argv[])
 	/* 
 	 * We pass off control to the subsystem that is specified by argv[1].
 	 */
-	return subsystem (argv[1], main_subsystem);
+	return call_subsystem (argv[1], main_subsystem);
 }
 
