@@ -18,13 +18,11 @@
  *	with this program; if not, write to the Free Software Foundation, Inc.,
  *	675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: pci.c,v 1.6 2001/12/17 01:35:50 kroah Exp $
- * 
  */
 
-#include "stddef.h"	/* for NULL */
-#include "stdlib.h"	/* for getenv() */
-#include "string.h"	/* for strtoul() */
+#include <stddef.h>	/* for NULL */
+#include <stdlib.h>	/* for getenv() */
+#include <string.h>	/* for strtoul() */
 #include "hotplug.h"
 
 #include "pci_modules.h"
@@ -89,7 +87,6 @@ static int match_vendor (unsigned int vendor, unsigned int device,
 	
 static int pci_add (void)
 {
-	struct pci_module_map *pci_module;
 	char *class_env;
 	char *id_env;
 	char *subsys_env;
@@ -147,7 +144,7 @@ int pci_handler (void)
 		return 1;
 	}
 
-	return subsystem (action, pci_subsystem);
+	return call_subsystem (action, pci_subsystem);
 }
 
 
